State

Enum State 

pub enum State {
    CheckingForUpdates(CheckingForUpdatesData),
    ErrorCheckingForUpdate(ErrorCheckingForUpdateData),
    NoUpdateAvailable(NoUpdateAvailableData),
    InstallationDeferredByPolicy(InstallationDeferredData),
    InstallingUpdate(InstallingData),
    WaitingForReboot(InstallingData),
    InstallationError(InstallationErrorData),
}
The set of states that a [Monitor] can receive during an update check.

An update check ends when it enters a terminal state, denoted below as the states on the right-hand side of the diagram with no arrows leading out of them.

State Machine Diagram

    +----------------------+     +---------------------------------+
    | checking_for_updates |---->|    error_checking_for_update    |
    +----------------------+     +---------------------------------+
               |
               |                 +---------------------------------+
               +---------------->|       no_update_available       |
               |                 +---------------------------------+
               |
               |                 +---------------------------------+
               +---------------->| installation_deferred_by_policy |
               |                 +---------------------------------+
               v
    +----------------------+     +---------------------------------+
    |  installing_update   |---->|       installation_error        |
    +----------------------+     +---------------------------------+
               |
               |                 +---------------------------------+
               +---------------->|       waiting_for_reboot        |
                                 +---------------------------------+

Variants



CheckingForUpdates(CheckingForUpdatesData)

The Manager is currently checking for an update.

Next states:

  • installing_update update is available and allowed by policy
  • error_checking_for_update on error
  • update_deferred_by_policy update is available but deferred by policy


ErrorCheckingForUpdate(ErrorCheckingForUpdateData)

The Manager encountered an error while checking for the existence of a a new update.

This is a terminal state



NoUpdateAvailable(NoUpdateAvailableData)

There is not update available at this time.

This is a terminal state



InstallationDeferredByPolicy(InstallationDeferredData)

The Manager has found an available update but is not acting on it at this time due to policy restrictions.

This is a terminal state



InstallingUpdate(InstallingData)

The Manager is installing the available update.

Next states:

  • waiting_for_reboot on success
  • installation_error on error


WaitingForReboot(InstallingData)

The update has been installed, and the device is waiting to be rebooted.

Next states:

  • (none, the device reboots)

This is a terminal state



InstallationError(InstallationErrorData)

The Manager encountered an error during the installation of the update.

This is a terminal state

Implementations

Source

impl State

pub fn ordinal(&self) -> u64